@@ -7,6 +7,7 @@ use RxPerl::Subscription;
 use RxPerl::Utils 'get_timer_subs', 'get_interval_subs';
 use RxPerl::Subject;
 use RxPerl::BehaviorSubject;
+use RxPerl::ReplaySubject;
 
 use Carp 'croak';
 use Scalar::Util qw/ weaken blessed reftype /;
@@ -15,8 +16,8 @@ use Exporter 'import';
 our @EXPORT_OK = qw/
     rx_behavior_subject rx_combine_latest rx_concat rx_defer rx_EMPTY
     rx_fork_join rx_from rx_from_event rx_from_event_array rx_interval
-    rx_merge rx_NEVER rx_observable rx_of rx_race rx_subject
-    rx_throw_error rx_timer
+    rx_merge rx_NEVER rx_observable rx_of rx_race rx_replay_subject
+    rx_subject rx_throw_error rx_timer
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
@@ -422,6 +423,8 @@ sub rx_race {
     });
 }
 
+sub rx_replay_subject { "RxPerl::ReplaySubject" }
+
 sub rx_subject { "RxPerl::Subject" }
 
 sub rx_throw_error {
